<?php
/*
Plugin Name: Preload
Version: 0.1
Description: Preload next/previous images when in the photo view.
Plugin URI: http://piwigo.org/ext/extension_view.php?eid=799
Author: fifreb
Author URI:
*/

define('PRELOAD_ID',       basename(dirname(__FILE__)));
define('PRELOAD_PATH' ,    PHPWG_PLUGINS_PATH . PRELOAD_ID . '/');

if (defined('IN_ADMIN'))
{
	add_event_handler('get_admin_plugin_menu_links', 'Preload_admin_menu');
}
else
{
	add_event_handler('loc_end_picture', 'Preload_populate_images');
}

add_event_handler('init', 'Preload_init');

function Preload_init()
{
	global $conf;

	$conf[PRELOAD_ID] = unserialize($conf[PRELOAD_ID]);
	if (!isset($conf[PRELOAD_ID]['imageCount'])) {
		$conf[PRELOAD_ID]['imageCount'] = 3;
	}
}

function Preload_admin_menu($menu)
{
  	$menu[] = array(
		'NAME' => 'Preload',
		'URL'  => get_root_url() . 'admin.php?page=plugin-' . PRELOAD_ID,
	);

	return $menu;
}

function Preload_populate_images()
{
        global $user, $page, $template, $conf, $pwg_loaded_plugins;

        $conf_nb_images = $conf[PRELOAD_ID]['imageCount'];

	if (isset($pwg_loaded_plugins['automatic_size'])) {
		$size = $template->smarty->getTemplateVars('automatic_size');
	} else {
		$size = pwg_get_session_var('picture_deriv', $conf['derivative_default_size']);
	}

	$ranks = array();
        $min_rank = max(1, $page['current_rank']-$conf_nb_images);
        $max_rank = min($page['last_rank'], $page['current_rank']+$conf_nb_images);
        $next_rank = -1;
	$prev_rank = -1;
	if ($page['current_rank'] > 1) {
		$prev_rank = $page['current_rank']-1;
	}
	if ($page['current_rank'] < $page['last_rank']) {
		$next_rank = $page['current_rank']+1;
	}
        for ($n = $min_rank; $n <= $max_rank; $n++) {
		$ranks[ $page['items'][ $n ]] = $n;
        }

        $query = '
        SELECT *
          FROM '.IMAGES_TABLE.'
          WHERE id IN ('.implode(',', array_keys($ranks)).')
        ;';

        $result = pwg_query($query);

	$urls = array();
        while ($row = pwg_db_fetch_assoc($result))
        {
		$rank = $ranks[$row['id']];
		$srcImg = new SrcImage($row);
                if ($rank != $page['current_rank']) {
			$urls[] = (new DerivativeImage($size, $srcImg))->get_url();
		}
		if ($user['theme'] == 'elegant') {
			if ($rank != $prev_rank && $rank != $next_rank) {
                		$urls[] = (new DerivativeImage('square', $srcImg))->get_url();
			}
		}
        }

	$template->assign('U_IMGNEXT', $urls );
	// Disable bad prefetch
	$template->assign('U_PREFETCH', null );

	$template->set_filenames( array('picture' => realpath(PRELOAD_PATH.'template/picture_preload.tpl')));

}

?>
